aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objective-c/GRPCClient/GRPCCall.h
diff options
context:
space:
mode:
authorGravatar Muxi Yan <mxyan@google.com>2017-08-30 15:36:47 -0700
committerGravatar Muxi Yan <mxyan@google.com>2017-08-30 15:37:45 -0700
commitc7c8e3cb1712438c64b1212911b6c22165982426 (patch)
tree0d173f0c0585582250af4d00d5101ac9e56bad6d /src/objective-c/GRPCClient/GRPCCall.h
parentf282c8f525788e6f15331bb6c94471012a7e5346 (diff)
Rename deadline to timeout
Diffstat (limited to 'src/objective-c/GRPCClient/GRPCCall.h')
-rw-r--r--src/objective-c/GRPCClient/GRPCCall.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/objective-c/GRPCClient/GRPCCall.h b/src/objective-c/GRPCClient/GRPCCall.h
index bcf4ae9cc7..26c920b973 100644
--- a/src/objective-c/GRPCClient/GRPCCall.h
+++ b/src/objective-c/GRPCClient/GRPCCall.h
@@ -170,9 +170,9 @@ extern id const kGRPCTrailersKey;
@property (atomic, copy, readwrite) NSString *serverName;
/**
* The deadline for the RPC call in milliseconds. If set to 0, the deadline will be infinity.
*/
-@property UInt64 deadline;
+@property UInt64 timeout;
/**
* The container of the request headers of an RPC conforms to this protocol, which is a subset of
@@ -170,9 +170,9 @@ extern id const kGRPCTrailersKey;
/**
- * The deadline for the RPC call in milliseconds. If set to 0, the deadline will be infinity.
+ * The timeout for the RPC call in milliseconds. If set to 0, the call will not timeout.
*/